#
# spec file for package flac
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           flac
Version:        1.3.0
Release:        12.1
Summary:        Free Lossless Audio Codec
License:        BSD-3-Clause and GPL-2.0+ and GFDL-1.2
Group:          Productivity/Multimedia/Sound/Utilities
Url:            http://flac.sourceforge.net/

#Git-Web:	https://git.xiph.org/?p=flac.git
#Git-Clone:	git://git.xiph.org/flac
Source:         http://downloads.xiph.org/releases/flac/%name-%version.tar.xz
Source2:        baselibs.conf
Patch1:         flac-ocloexec.patch
Patch2:         0001-Allow-use-of-openSSL.patch  
Patch5:         0001-getopt_long-not-broken-here.patch
Patch6:         flac-fix-CVE-2014-8962.patch
Patch7:         flac-fix-CVE-2014-9028.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf >= 2.60
BuildRequires:  automake >= 1.11
BuildRequires:  gcc-c++
BuildRequires:  libogg-devel
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRequires:  xz
%ifarch %{ix86}
BuildRequires:  nasm
%endif
%ifarch ppc64
# bug437293
Obsoletes:      flac-64bit
%endif

%description
FLAC is an open source lossless audio codec developed by Josh Coalson.

%package -n libFLAC8
Summary:        Free Lossless Audio Codec Library
Group:          System/Libraries
Obsoletes:      libflac < %{version}
Provides:       libflac = %{version}

%description -n libFLAC8
This package contains the library for FLAC (Free Lossless Audio Codec)
developed by Josh Coalson.

%package -n libFLAC++6
Summary:        Free Lossless Audio Codec Library
Group:          System/Libraries

%description -n libFLAC++6
This package contains the C++ library for FLAC (Free Lossless Audio
Codec) developed by Josh Coalson.

%package devel
Summary:        FLAC Library Development Package
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libFLAC++6 = %{version}
Requires:       libFLAC8 = %{version}
Requires:       libstdc++-devel

%description devel
This package contains the files needed to compile programs that use the
FLAC library.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1

%build
touch config.rpath
autoreconf --force --install
%define warn_flags -O3 -W -Wall -Wstrict-prototypes -Wformat-security
export CFLAGS="%{optflags} %{warn_flags}"
export CXXFLAGS="$CFLAGS"
%configure --disable-thorough-tests \
	--disable-xmms-plugin \
	--disable-static \
	--disable-rpath \
	--with-pic \
	--enable-sse

make %{?_smp_mflags} V=1

%install
make install DESTDIR="%buildroot" docdir="%_docdir/%name"
rm -f "%buildroot/%_libdir"/*.la
# documents
cp -a AUTHORS README COPYING.* %{buildroot}%{_docdir}/%{name}

%check
make check %{?_smp_mflags}

%post -n libFLAC8 -p /sbin/ldconfig

%postun -n libFLAC8 -p /sbin/ldconfig

%post -n libFLAC++6 -p /sbin/ldconfig

%postun -n libFLAC++6 -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc %{_docdir}/%{name}
%{_bindir}/*
%{_mandir}/man*/*

%files -n libFLAC8
%defattr(-, root, root)
%{_libdir}/libFLAC.so.8*

%files -n libFLAC++6
%defattr(-, root, root)
%{_libdir}/libFLAC++.so.6*

%files devel
%defattr(-, root, root)
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_datadir}/aclocal/*.m4

%changelog
* Wed Sep 14 2016 tchvatal@suse.com
- Remove problematic patch bsc#998612:
  * flac-fix-pkgconfig.patch
* Wed Nov 26 2014 tiwai@suse.de
- A couple of security fixes:
  * flac-fix-CVE-2014-8962.patch:
    arbitrary code execution by a stack overflow (CVE-2014-8962,
    bnc#906831)
  * flac-fix-CVE-2014-9028.patch:
    Heap overflow via specially crafted .flac files (CVE-2014-9028,
    bnc#907016)
* Mon Jul  1 2013 jengelh@inai.de
- Update to final upstream release 1.3.0
  * No user-visible changes
- More robust make install call
* Sun May 26 2013 crrodriguez@opensuse.org
- Update to flac 1.3.0pre4 (packaged as 1.2.99_git* to avoid
  messing with RPM versioning)
  * Mostly non-linux related bugfixes plus autotools fixes
  - flac-openssl.patch --> 0001-Allow-use-of-openSSL.patch
  - remove flac-1.2.1-automake1_13.patch, fixed in upstream.
  - add 0001-getopt_long-not-broken-here.patch, FLAC bundles
  GNU-compatible getopt_long for broken OS, but we do have
  a functional version in libc already.
* Mon Apr 22 2013 cfarrell@suse.com
- license update: BSD-3-Clause and GPL-2.0+ and GFDL-1.2
  Numerous GPL-2.0+ licensed files;documtation is GFDL-1.2
* Thu Feb 28 2013 seife+obs@b1-systems.com
- add flac-1.2.1-automake1_13.patch, fix build with automake-1.13.1
* Tue Dec 18 2012 idonmez@suse.com
- Add flac-fix-pkgconfig.patch to fix includedir in the pkgconfig
  files.
* Sat Dec  8 2012 crrodriguez@opensuse.org
- add xz buildrequires for old distros.
* Sat Dec  8 2012 crrodriguez@opensuse.org
- Update to current git
  * patches deleted:
  - flac-1.2.1-asm.patch
  - flac-1.2.1-bitreader.patch
  - flac-gcc43-fixes.diff
  - flac-gcc47.patch
  - flac-leaks.patch
  - flac-no-xmms.diff
  - flac-visibility.patch
  - flac-printf-format-fix.diff
  All Upstreamed either by us or other distros.
- Add flac-openssl.patch, do crypto with openssl (not wanted upstream)
- Restore make check
* Tue Sep  4 2012 schwab@linux-m68k.org
- Don't ignore $(AM_CFLAGS).
- Remove ppc patch.
* Tue Mar 13 2012 dimstar@opensuse.org
- Add flac-gcc47.patch: Replacing strcpy without 'lenght
  limitation' with strncpy, limited to 4 chars. This is safe, as we
  check the length already to be sure it is 4 chars, yet do not
  suffer from the problem that strcpy wants to add a '\0' char in
  plus to the target string.
* Thu Mar  8 2012 dvaleev@suse.com
- don't use fvisibility=hidden on ppc. As it can't find symbols
  afterwards
* Fri Jan 27 2012 crrodriguez@opensuse.org
- Fix some memory and resources leak.
- Link shared libraries with -Bsymbolic-functions
- annotate relevant functions with proper attributes to
  allow the compiler generate better code (attribute hot. alloc_size)
* Tue Jan 24 2012 crrodriguez@opensuse.org
- Support symbol visibility features
- Disable test suite, nothing wrong with it, it just
  takes too long to run and uses private/hidden symbols to
  test flac's internals.
* Sun Nov 20 2011 crrodriguez@opensuse.org
- Use O_CLOEXEC in all library code.
* Sat Oct  1 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Wed Sep 28 2011 crrodriguez@opensuse.org
- Build with --enable-sse, this only disables runtime
  checking if the *OS* supports SSE, which registers a
  SIGILL signal handler then tries to execute SSE code...
  it still tests the running *CPU* though.
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
- Add flac-devel to baselibs
* Sat Aug  6 2011 crrodriguez@opensuse.org
- Do not build with -fno-strict-aliasing since is no longer
  required.
- Impoer two patches from redhat, one speeds up decoding and
  the other enables the working ASM optimizations.
* Wed Dec  8 2010 cristian.rodriguez@opensuse.org
- run make check, but only the basic test suite, complete
  one takes hours.
* Wed Dec 16 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed May 21 2008 cthiel@suse.de
- fix baselibs.conf
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Dec 13 2007 crrodriguez@suse.de
- disable static libraries
- remove uneeded dependency on libogg-devel in the -devel package
- remove "la" files
* Mon Oct 22 2007 tiwai@suse.de
- fix build with gcc 4.3.
* Fri Oct 12 2007 tiwai@suse.de
- updated to version 1.2.1:
  * VUL-0: flac integer overflows (#333278)
  * new --keep-foreign-metadata, --no-utf8-convert options
  * changed default extension for Ogg FLAC to .oga
  * many other fixes, see changelog
* Wed Jul 25 2007 tiwai@suse.de
- updated to version 1.2.0:
  * small encoding speedups
  * runtime SSE OS support
  * fixed bug with invalid seek tables
  * added FLAC__format_sample_rate_is_subset(),
    FLAC::Decoder::Stream::get_decoder_position()
- clean up spec file
* Fri Jun  8 2007 tiwai@suse.de
- add provides and obsolets for libflac.
* Tue Jun  5 2007 tiwai@suse.de
- split to packages libFLAC8 and libFLAC++6 to follow more the
  library packaging policy.
* Tue Apr 10 2007 tiwai@suse.de
- fix post and postun for libflac.
- fix compile warnings
* Wed Apr  4 2007 tiwai@suse.de
- updated to version 1.1.4:
  * improved compression with no change to format or decrease
    in speed.
  * encoding and decoding speedups for all modes. Encoding at
  - 8 is twice as fast.
  * large format support.
  * supports FLAC and Ogg FLAC as input encoder.
  * misc bug fixes
- split library to libflac sub-package to reduce package
  dependencies.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jul  7 2005 tiwai@suse.de
- fix Requires of devel subpackage.
* Wed May 25 2005 tiwai@suse.de
- updated to version 1.1.2.
* Fri Feb 25 2005 tiwai@suse.de
- split flac-xmms and flac-bmp plugins to another spec file
  to avoid too deep dependencies.
* Fri Jan 28 2005 tiwai@suse.de
- fix many compile warnings
- add BMP plugin support
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 1.1.1.
* Tue Aug 24 2004 tiwai@suse.de
- fixed neededforbuild for xmms.
* Mon Apr 26 2004 ro@suse.de
- add -fno-strict-aliasing
* Wed Jan 21 2004 tiwai@suse.de
- fixed quoting in m4 files.
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig to %%postun
* Tue May 27 2003 ro@suse.de
- remove unpackaged files from buildroot
* Tue Apr  1 2003 ro@suse.de
- added xmms-devel to neededforbuild
* Thu Feb 13 2003 tiwai@suse.de
- fixed the installation path of xmms plugin.
- added la file for plugin.
* Mon Jan 27 2003 tiwai@suse.de
- updated to version 1.1.0.
* Wed Nov 27 2002 tiwai@suse.de
- added the compatible layer for version 1.0.3 (flac-compat.dif).
* Mon Nov 25 2002 tiwai@suse.de
- updated to version 1.0.4.
- fixed neeededforbuild: xf86 -> x-devel-packages.
- added id3lib to neededforbuild.
- regenrated prototype patches.  renamed the patch to avoid
  name confliction.
* Tue Sep 17 2002 pthomas@suse.de
- Add -lsdc++ to LIBADD in src/libFLAC++/Makefile.am to work
  around a bug in libtool 1.4.2.
- Properly use (void) not () in prototypes.
- Omit -I/usr/include from LIBFLAC_CFLAGS in libFLAC.m4 as
  it's searched by default.
- Omit -L/usr/lib from LIBFLAC_LIBS in libFLAC.m4
* Mon Jul 29 2002 tiwai@suse.de
- added %%run_ldconfig.
* Fri Jul  5 2002 tiwai@suse.de
- updated to version 1.0.3.
* Mon Jun 24 2002 tiwai@suse.de
- fixed file permission of xmms plugins.
* Tue May 21 2002 tiwai@suse.de
- added missing *.so to the filelist.
* Tue May 21 2002 tiwai@suse.de
- initial version: 1.0.2.
